==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Detenga con el mismo atajo de teclado
o haga clic en el icono de la bandeja</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Error al guardar. Por favor guárdelo en su carpeta personal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de pantalla finalizada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>área-de-selección</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado en %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Portapapeles</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Guardando el archivo de la grabación de pantalla, por favor espere...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Debido a que los efectos de ventana se desactivaron, el proceso de grabado se detuvo</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Grabación finalizada</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado en %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grabación</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Captura empieza en %1 segundos</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Ingrese el texto aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Iniciar/Captura</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Salir/Guardar</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Dibujo</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajuste de tamaño</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inicio rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura de pantalla de ventana</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Captura temporizada</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de pantalla completa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumentar altura hacia arriba</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumentar altura hacia abajo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumentar ancho hacia la izquierda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumentar ancho hacia la derecha</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Disminuir altura hacia arriba</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Disminuir altura hacia abajo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Disminuir ancho hacia la izquierda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Disminuir ancho hacia la derecha</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar grabación</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Iniciar/Detener</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratón</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Difuminar</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Pixelar</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Sonido activado</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Micrófono</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Audio del sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Sonido apagado</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Mostrar pulsación de tecla</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Ocultar pulsación de tecla</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Encender cámara web</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Apagar cámara web</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Mostrar clic</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Guardar en</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Portapapeles</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostrar puntero</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratón</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mostrar puntero</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajustar el área de grabación dentro de %1*%2 para obtener un mejor efecto de vídeo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Grabaciones</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Detenga con el mismo atajo de teclado
o haga clic en el icono de la bandeja</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>No gire la pantalla durante la grabación</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Error al guardar. Por favor guárdelo en su carpeta personal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de pantalla finalizada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>área-de-selección</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado en %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Portapapeles</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Guardando el archivo de la grabación de pantalla, por favor espere...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Debido a que los efectos de ventana se desactivaron, el proceso de grabado se detuvo</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>La captura de pantalla se ha guardado en el álbum.</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Captura de pantalla fallida</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Capturar desplazamiento</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Grabación finalizada</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado en %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grabación</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Captura empieza en %1 segundos</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Busca ayuda.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>No se ha podido realizar una captura de pantalla continua.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Fondo del área de desplazamiento alcanzado</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Ha alcanzado la longitud máxima</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ajustar el área de captura</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Desplaza la rueda del ratón o haz clic para hacer una captura de pantalla con desplazamiento</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Reducir la velocidad de desplazamiento</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Invalid area, click to </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Ingrese el texto aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Iniciar/Captura</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Salir/Guardar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajuste de tamaño</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inicio rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura de pantalla de ventana</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Captura temporizada</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de pantalla completa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumentar altura hacia arriba</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumentar altura hacia abajo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumentar ancho hacia la izquierda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumentar ancho hacia la derecha</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Disminuir altura hacia arriba</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Disminuir altura hacia abajo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Disminuir ancho hacia la izquierda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Disminuir ancho hacia la derecha</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar grabación</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Iniciar/Detener</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratón</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Capturar desplazamiento</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Difuminar</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Pixelar</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Sonido activado</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Micrófono</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Audio del sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Sonido apagado</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Mostrar pulsación de tecla</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Ocultar pulsación de tecla</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Encender cámara web</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Apagar cámara web</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Mostrar clic</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Guardar en</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Portapapeles</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostrar puntero</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratón</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mostrar puntero</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Capturar desplazamiento</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajustar el área de grabación dentro de %1*%2 para obtener un mejor efecto de vídeo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>No es posible grabar la pantalla en este momento</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
</TS>
